@@ -1,36 +1,47 @@
 /* rsa-encrypt.c
- *
- */
 
-/* nettle, low-level cryptographics library
- *
- * Copyright (C) 2002 Niels Mller
- *  
- * The nettle library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or (at your
- * option) any later version.
- * 
- * The nettle library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
- * License for more details.
- * 
- * You should have received a copy of the GNU Lesser General Public License
- * along with the nettle library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
- */
+   Copyright (C) 2002 Niels Möller
+
+   This file is part of GNU Nettle.
+
+   GNU Nettle is free software: you can redistribute it and/or
+   modify it under the terms of either:
+
+     * the GNU Lesser General Public License as published by the Free
+       Software Foundation; either version 3 of the License, or (at your
+       option) any later version.
+
+   or
+
+     * the GNU General Public License as published by the Free
+       Software Foundation; either version 2 of the License, or (at your
+       option) any later version.
+
+   or both in parallel, as here.
+
+   GNU Nettle is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received copies of the GNU General Public License and
+   the GNU Lesser General Public License along with this program.  If
+   not, see http://www.gnu.org/licenses/.
+*/
    
 #if HAVE_CONFIG_H
 # include "config.h"
 #endif
 
+#include <assert.h>
 #include <ctype.h>
 #include <errno.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#ifdef WIN32
+#include <fcntl.h>
+#endif
 
 /* string.h must be included before gmp.h */
 #include "bignum.h"
@@ -90,35 +101,54 @@ write_bignum(FILE *f, mpz_t x)
   return res;
 }
 
+#define BLOCK_SIZE (AES_BLOCK_SIZE * 100)
+
 static int
 process_file(struct rsa_session *ctx,
 	     FILE *in, FILE *out)
 {
-  uint8_t buffer[AES_BLOCK_SIZE * 100];
-  unsigned leftover;
-  unsigned padding;
-
-  padding = leftover = 0;
+  uint8_t buffer[BLOCK_SIZE + SHA1_DIGEST_SIZE];
 
   for (;;)
     {
-      size_t size = fread(buffer, 1, sizeof(buffer), in);
-      if (ferror(in))
-	{
-	  werror("Reading input failed: %s\n", strerror(errno));
-	  return 0;
-	}
-
+      size_t size = fread(buffer, 1, BLOCK_SIZE, in);
       hmac_sha1_update(&ctx->hmac, size, buffer);
-      if (size < sizeof(buffer))
+
+      if (size < BLOCK_SIZE)
 	{
-	  /* Setting padding != ends the loop */
+	  unsigned leftover;
+	  unsigned padding;
+
+	  if (ferror(in))
+	    {
+	      werror("Reading input failed: %s\n", strerror(errno));
+	      return 0;
+	    }
+	  
 	  leftover = size % AES_BLOCK_SIZE;
 	  padding = AES_BLOCK_SIZE - leftover;
-	  size -= leftover;
 
-	  if (!size)
-	    break;
+	  assert (size + padding <= BLOCK_SIZE);
+	  
+	  if (padding > 1)
+	    yarrow256_random(&ctx->yarrow, padding - 1, buffer + size);
+
+	  size += padding;
+
+	  buffer[size - 1] = padding;
+	  CBC_ENCRYPT(&ctx->aes, aes_encrypt, size, buffer, buffer);
+
+	  assert (size + SHA1_DIGEST_SIZE <= sizeof(buffer));
+
+	  hmac_sha1_digest(&ctx->hmac, SHA1_DIGEST_SIZE, buffer + size);
+	  size += SHA1_DIGEST_SIZE;
+
+	  if (!write_string(out, size, buffer))
+	    {
+	      werror("Writing output failed: %s\n", strerror(errno));
+	      return 0;
+	    }
+	  return 1;
 	}
 
       CBC_ENCRYPT(&ctx->aes, aes_encrypt, size, buffer, buffer);
@@ -127,29 +157,16 @@ process_file(struct rsa_session *ctx,
 	  werror("Writing output failed: %s\n", strerror(errno));
 	  return 0;
 	}
-
-      if (padding)
-	{
-	  if (leftover)
-	    memcpy(buffer, buffer + size, leftover);
-
-	  break;
-	}
     }
-  if (padding > 1)
-    yarrow256_random(&ctx->yarrow, padding - 1, buffer + leftover);
+}
 
-  buffer[AES_BLOCK_SIZE - 1] = padding;
-  CBC_ENCRYPT(&ctx->aes, aes_encrypt, AES_BLOCK_SIZE, buffer, buffer);
-  hmac_sha1_digest(&ctx->hmac, SHA1_DIGEST_SIZE, buffer + AES_BLOCK_SIZE);
-
-  if (!write_string(out, AES_BLOCK_SIZE + SHA1_DIGEST_SIZE, buffer))
-    {
-      werror("Writing output failed: %s\n", strerror(errno));
-      return 0;
-    }
-
-  return 1;
+static void
+usage (FILE *out)
+{
+  fprintf (out, "Usage: rsa-encrypt [OPTIONS] PUBLIC-KEY < cleartext\n"
+	   "Options:\n"
+	   "   -r, --random=FILE   seed file for randomness generator\n"
+	   "       --help          display this help\n");  
 }
 
 int
@@ -164,8 +181,17 @@ main(int argc, char **argv)
   int c;
   const char *random_name = NULL;
 
-  /* FIXME: --help option. */
-  while ( (c = getopt(argc, argv, "o:r:")) != -1)
+  enum { OPT_HELP = 300 };
+  
+  static const struct option options[] =
+    {
+      /* Name, args, flag, val */
+      { "help", no_argument, NULL, OPT_HELP },
+      { "random", required_argument, NULL, 'r' },
+      { NULL, 0, NULL, 0}
+    };
+  
+  while ( (c = getopt_long(argc, argv, "o:r:", options, NULL)) != -1)
     switch (c)
       {
       case 'r':
@@ -175,6 +201,9 @@ main(int argc, char **argv)
       case '?':
 	return EXIT_FAILURE;
 
+      case OPT_HELP:
+	usage(stdout);
+	return EXIT_SUCCESS;
       default:
 	abort();
       }
@@ -184,7 +213,7 @@ main(int argc, char **argv)
 
   if (argc != 1)
     {
-      werror("Usage: rsa-encrypt [-r random-file] PUBLIC-KEY < cleartext\n");
+      usage (stderr);
       return EXIT_FAILURE;
     }
 
@@ -212,6 +241,11 @@ main(int argc, char **argv)
 
   rsa_session_set_encrypt_key(&ctx, &info);
   
+#ifdef WIN32
+  _setmode(0, O_BINARY);
+  _setmode(1, O_BINARY);
+#endif
+
   write_version(stdout);
   
   mpz_init(x);
@@ -226,11 +260,13 @@ main(int argc, char **argv)
     }
 
   write_bignum(stdout, x);
-  
+
+  mpz_clear (x);
+
   if (!process_file(&ctx,
 		    stdin, stdout))
     return EXIT_FAILURE;
-  
+
   rsa_public_key_clear(&key);
 
   return EXIT_SUCCESS;
