@@ -142,6 +142,22 @@ mpn_zero (mp_ptr ptr, mp_size_t n)
 }
 #endif /* !GMP_HAVE_mpn_copyd */
 
+void
+cnd_swap (mp_limb_t cnd, mp_limb_t *ap, mp_limb_t *bp, mp_size_t n)
+{
+  mp_limb_t mask = - (mp_limb_t) (cnd != 0);
+  mp_size_t i;
+  for (i = 0; i < n; i++)
+    {
+      mp_limb_t a, b, t;
+      a = ap[i];
+      b = bp[i];
+      t = (a ^ b) & mask;
+      ap[i] = a ^ t;
+      bp[i] = b ^ t;
+    }
+}
+
 /* Additional convenience functions. */
 
 int
@@ -227,6 +243,69 @@ mpn_set_base256 (mp_limb_t *rp, mp_size_t rn,
     }
 }
 
+void
+mpn_set_base256_le (mp_limb_t *rp, mp_size_t rn,
+		    const uint8_t *xp, size_t xn)
+{
+  size_t xi;
+  mp_limb_t out;
+  unsigned bits;
+  for (xi = 0, out = bits = 0; xi < xn && rn > 0; )
+    {
+      mp_limb_t in = xp[xi++];
+      out |= (in << bits) & GMP_NUMB_MASK;
+      bits += 8;
+      if (bits >= GMP_NUMB_BITS)
+	{
+	  *rp++ = out;
+	  rn--;
+
+	  bits -= GMP_NUMB_BITS;
+	  out = in >> (8 - bits);
+	}
+    }
+  if (rn > 0)
+    {
+      *rp++ = out;
+      if (--rn > 0)
+	mpn_zero (rp, rn);
+    }
+}
+
+void
+mpn_get_base256_le (uint8_t *rp, size_t rn,
+		    const mp_limb_t *xp, mp_size_t xn)
+{
+  unsigned bits;
+  mp_limb_t in;
+  for (bits = in = 0; xn > 0 && rn > 0; )
+    {
+      if (bits >= 8)
+	{
+	  *rp++ = in;
+	  rn--;
+	  in >>= 8;
+	  bits -= 8;
+	}
+      else
+	{
+	  uint8_t old = in;
+	  in = *xp++;
+	  xn--;
+	  *rp++ = old | (in << bits);
+	  rn--;
+	  in >>= (8 - bits);
+	  bits += GMP_NUMB_BITS - 8;
+	}
+    }
+  while (rn > 0)
+    {
+      *rp++ = in;
+      rn--;
+      in >>= 8;
+    }
+}
+
 mp_limb_t *
 gmp_alloc_limbs (mp_size_t n)
 {
